@@ -1,6 +1,7 @@
 from __future__ import annotations
 from __future__ import annotations
 
+import datetime
 from dataclasses import dataclass
 from datetime import date
 
@@ -21,9 +22,11 @@ class SportState:
 
     @staticmethod
     def from_dict(sport_state_dict) -> SportState:
+        season_start_date = None if sport_state_dict.get("season_start_date") is None else datetime.datetime.strptime(
+            sport_state_dict.get("season_start_date"), "%Y-%m-%d").date()
         return SportState(week=sport_state_dict.get("week"),
                           season_type=SeasonType.from_str(sport_state_dict.get("season_type")),
-                          season_start_date=sport_state_dict.get("season_start_date"),
+                          season_start_date=season_start_date,
                           season=sport_state_dict.get("season"),
                           previous_season=sport_state_dict.get("previous_season"),
                           leg=sport_state_dict.get("leg"),
